{% extends 'base.html' %}

{% block title %}GEA | Login{% endblock %}

{% block content %}
<h2><i class="fa fa-sign-in"></i> <strong>GEA</strong> Login</h2>
<form class="form-horizontal col-md-offset-4 col-lg-4" method="post">{% csrf_token %}
  <fieldset>
    <div class="form-group">
      <table class="table table-striped table-condensed table-hover">
      {{ form.as_table }}
      </table>
      <button type="submit" class="btn btn-primary pull-right"><i class="fa fa-sign-in"></i> &nbsp;Ingresar</button>
    </div>
  </fieldset>
</form>
{% endblock %}
{% block top %}{% endblock %}

