{% extends "menu.html" %}

{# set menu in active mode #}
{% block nav-tool-dvapi %} class="active"{% endblock %}

{% block title %}GEA | Dígito Verificador{% endblock %}

{% block content %}
<form class="form-horizontal col-lg-6" method="post">{% csrf_token %}
  <legend><i class="fa fa-calculator"></i> Calcular Dígito Verificador API</legend>
  <fieldset>
    <div class="form-group">
      <table class="table table-condensed table-hover">
      {{ form.as_table }}
      </table>
      <div class="well well-sm col-lg-10">
        Resultado: <strong>{{ dv }}</strong>
      </div>
        <button type="submit" class="btn btn-primary pull-right">Calcular</button>
    </div>
  </fieldset>
</form>
{% endblock %}
