<!DOCTYPE html>
<html lang="es">

<head>
  {% load static %}
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="Gesti&oacute;n de Expedientes de Agrimensores">
  <meta name="author" content="GEAdevel">
  <link rel="shortcut icon" href="{% static 'img/folder-o.png' %}">
  <title>{% block title %}GEA{% endblock title %}</title>
  <!-- Bootstrap core CSS -->
  <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">
  <link href="{% static 'css/font-awesome.min.css' %}" rel="stylesheet">
  {% block css %}
  {% endblock css %}
  <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
  <!--[if lt IE 9]>
      <script src="/static/js/html5shiv.js"></script>
      <script src="/static/js/respond.min.js"></script>
    <![endif]-->
  {% block js %}
  {% endblock js %}
</head>
<!-- <body ng-app="base"> -->

<body>
  <!-- MENU -->
  {% block menu %}
  {% endblock menu %}
  <div class="container">
    {% block content %}
    {% endblock content %}
    {% block footer %}
    <!-- FOOTER -->
    <footer>
      <div class="container">
        <div class="row clearfix">
          <div class="col-md-12 column">
            <hr>
            {% block top %}<p class="pull-right"><i class="fa fa-chevron-up"></i> <a href="#">Arriba</a></p>
            {% endblock top %}
            <p>GEA &copy; {% now "Y" %} &middot; Todos los derechos reservados. <a rel="license"
                href="https://creativecommons.org/licenses/by-nc-sa/3.0/" target="_blank"><img
                  alt="Creative Commons License" style="border-width:0"
                  src="https://i.creativecommons.org/l/by-nc-sa/3.0/br/80x15.png" /></a>
            </p>
          </div>
        </div>
      </div><!-- footer-container -->
    </footer>
    {% endblock footer %}
  </div> <!-- /container -->
  <!-- Bootstrap core JavaScript -->
  <!-- Placed at the end of the document so the pages load faster -->
  <script src="//code.jquery.com/jquery-1.11.3.min.js"></script>
  <script src="{% static 'js/bootstrap.min.js' %}"></script>
</body>

</html>